# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['micone',
 'micone.config',
 'micone.conversion',
 'micone.logging',
 'micone.main',
 'micone.pipelines',
 'micone.pipelines.src.network_inference.bootstrap.resample.processes',
 'micone.pipelines.src.network_inference.correlation.pearson.processes',
 'micone.pipelines.src.network_inference.correlation.spearman.processes',
 'micone.pipelines.src.network_inference.direct.flashweave.processes',
 'micone.pipelines.src.network_inference.network.make_network_with_pvalue.processes',
 'micone.pipelines.src.network_inference.network.make_network_wo_pvalue.processes',
 'micone.pipelines.src.otu_assignment.chimera_checking.remove_bimera.processes',
 'micone.pipelines.src.otu_assignment.denoise_cluster.closed_reference.processes',
 'micone.pipelines.src.otu_assignment.denoise_cluster.dada2.processes',
 'micone.pipelines.src.otu_assignment.denoise_cluster.de_novo.processes',
 'micone.pipelines.src.otu_assignment.denoise_cluster.deblur.processes',
 'micone.pipelines.src.otu_assignment.denoise_cluster.open_reference.processes',
 'micone.pipelines.src.otu_assignment.sequence_processing.demultiplex_illumina.processes',
 'micone.pipelines.src.otu_assignment.sequence_processing.trim_filter_adapter.processes',
 'micone.pipelines.src.otu_assignment.sequence_processing.trim_filter_fixed.processes',
 'micone.pipelines.src.otu_processing.export.biom2tsv.processes',
 'micone.pipelines.src.otu_processing.filter.abundance.processes',
 'micone.pipelines.src.otu_processing.filter.group.processes',
 'micone.pipelines.src.otu_processing.transform.normalize.processes',
 'micone.pipelines.src.tax_assignment.assign.blast.processes',
 'micone.pipelines.src.tax_assignment.assign.naive_bayes.processes',
 'micone.setup',
 'micone.utils',
 'micone.validation']

package_data = \
{'': ['*'],
 'micone.config': ['configs/*'],
 'micone.pipelines': ['envs/micone-dada2/*',
                      'envs/micone-flashweave/*',
                      'envs/micone-mldm/*',
                      'envs/micone-netcomi/*',
                      'envs/micone-propr/*',
                      'envs/micone-qiime1/*',
                      'envs/micone-qiime2/*',
                      'envs/micone-sparcc/*',
                      'envs/micone-spieceasi/*',
                      'src/network_inference/bootstrap/pvalue/*',
                      'src/network_inference/bootstrap/pvalue/processes/*',
                      'src/network_inference/bootstrap/resample/*',
                      'src/network_inference/correlation/pearson/*',
                      'src/network_inference/correlation/propr/*',
                      'src/network_inference/correlation/propr/processes/*',
                      'src/network_inference/correlation/sparcc/*',
                      'src/network_inference/correlation/sparcc/processes/*',
                      'src/network_inference/correlation/spearman/*',
                      'src/network_inference/direct/flashweave/*',
                      'src/network_inference/direct/mldm/*',
                      'src/network_inference/direct/mldm/processes/*',
                      'src/network_inference/direct/spieceasi/*',
                      'src/network_inference/direct/spieceasi/processes/*',
                      'src/network_inference/network/make_network_with_pvalue/*',
                      'src/network_inference/network/make_network_wo_pvalue/*',
                      'src/otu_assignment/chimera_checking/remove_bimera/*',
                      'src/otu_assignment/chimera_checking/uchime/*',
                      'src/otu_assignment/chimera_checking/uchime/processes/*',
                      'src/otu_assignment/denoise_cluster/*',
                      'src/otu_assignment/denoise_cluster/closed_reference/*',
                      'src/otu_assignment/denoise_cluster/dada2/*',
                      'src/otu_assignment/denoise_cluster/de_novo/*',
                      'src/otu_assignment/denoise_cluster/deblur/*',
                      'src/otu_assignment/denoise_cluster/open_reference/*',
                      'src/otu_assignment/sequence_processing/demultiplex_454/*',
                      'src/otu_assignment/sequence_processing/demultiplex_454/processes/*',
                      'src/otu_assignment/sequence_processing/demultiplex_illumina/*',
                      'src/otu_assignment/sequence_processing/join_reads/*',
                      'src/otu_assignment/sequence_processing/join_reads/processes/*',
                      'src/otu_assignment/sequence_processing/join_reads_demux/*',
                      'src/otu_assignment/sequence_processing/trim_filter_adapter/*',
                      'src/otu_assignment/sequence_processing/trim_filter_fixed/*',
                      'src/otu_processing/export/biom2tsv/*',
                      'src/otu_processing/filter/abundance/*',
                      'src/otu_processing/filter/group/*',
                      'src/otu_processing/filter/partition/*',
                      'src/otu_processing/transform/normalize/*',
                      'src/tax_assignment/assign/blast/*',
                      'src/tax_assignment/assign/naive_bayes/*',
                      'src/tax_assignment/phylogeny/alignment/*',
                      'src/tax_assignment/phylogeny/diversity/*']}

install_requires = \
['Jinja2>=2.11.2,<3.0.0',
 'biom-format>=2.1.10,<3.0.0',
 'click>=7.1.2,<8.0.0',
 'ete3>=3.1.2,<4.0.0',
 'h5py>=3.1.0,<4.0.0',
 'halo>=0.0.31,<0.0.32',
 'jinja2schema>=0.1.4,<0.2.0',
 'loguru>=0.5.3,<0.6.0',
 'matplotlib>=3.3.3,<4.0.0',
 'networkx>=2.5,<3.0',
 'numpy>=1.19.4,<2.0.0',
 'pandas>=1.2.0,<2.0.0',
 'schematics>=2.1.0,<3.0.0',
 'simplejson>=3.17.2,<4.0.0',
 'statsmodels>=0.12.1,<0.13.0',
 'toml>=0.10.2,<0.11.0']

extras_require = \
{'docs': ['Sphinx>=3.4.2,<4.0.0', 'sphinx-rtd-theme>=0.5.1,<0.6.0']}

entry_points = \
{'console_scripts': ['micone = micone.cli:main']}

setup_kwargs = {
    'name': 'micone',
    'version': '0.7.0',
    'description': 'The Microbial Co-occurrence Network Explorer',
    'long_description': None,
    'author': 'Dileep Kishore',
    'author_email': 'dkishore@bu.edu',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'extras_require': extras_require,
    'entry_points': entry_points,
    'python_requires': '>=3.8,<3.9',
}


setup(**setup_kwargs)
